@@ -3,8 +3,8 @@
  *
  * libyahoo2 is available at http://libyahoo2.sourceforge.net/
  *
- * $Revision: 364 $
- * $Date: 2010-04-13 14:40:19 +0530 (Tue, 13 Apr 2010) $
+ * $Revision: 373 $
+ * $Date: 2010-06-02 13:55:25 -0700 (Wed, 02 Jun 2010) $
  * 
  * Copyright (C) 2002-2004, Philip S Tellis <philip.tellis AT gmx.net>
  * Copyright (C) 2009, Siddhesh Poyarekar <siddhesh.poyarekar@gmail.com>
@@ -873,7 +873,7 @@ static void ext_yahoo_login(yahoo_local_account * ylad, int login_mode)
 
 	ylad->id = yahoo_init_with_attributes(ylad->yahoo_id, ylad->password, 
 			"local_host", local_host,
-			"pager_port", 23,
+			"pager_port", 5050,
 			NULL);
 	ylad->status = YAHOO_STATUS_OFFLINE;
 	yahoo_login(ylad->id, login_mode);
@@ -1184,7 +1184,7 @@ static int ext_yahoo_connect_async(int id, const char *host, int port,
 
 	struct _conn *c;
 
-	LOG(("Connecting to %s", host));
+	LOG(("Connecting to %s:%d", host, port));
 	
 	if(!(server = gethostbyname(host))) {
 		errno=h_errno;
@@ -1240,7 +1240,7 @@ static int ext_yahoo_connect_async(int id, const char *host, int port,
 
 		ext_yahoo_close(c);
 
-		callback(NULL, 0, data);
+		callback(NULL, errno, data);
 		return -1;
 	}
 }
